/**
 * Stores a property parameter without any type check
 * @param path [in] property path
 * @param value [in] property value
 */
Property.setSavedProperty = function (path, value) {
    try 
    {	if (lInfo!=null)
        	lInfo.logln('store at |' + path + "| value: |" + value + "|" );
        Property.setProperty(path, value);
        Property.setFlag(path, 'ARCHIVE', true);
    }
    catch (e)
    {
        if (lWarn!=null)
        	lWarn.logln("Exception beim Property.setSavedProperty " + e + " Path " + path  + " value " + value);
    }        
}

/**
 * Store a integer property parameter.
 * converts provided value whenever possible to an integer. Discard the the value if this is not possible.
 * @param path [in] property path
 * @param value [in] value to store should be integer
 * @returns {Boolean} returns false if value could not be converted to integer
 */
function checkAndStoreIntParameter(path, value) {
    try 
    {
        if (lInfo!=null)
        	lInfo.logln('store integer at |' + path + "| value: |" + value + "|" );
        var sucessCode = false;
        var intValue = parseInt("" + value,10);
        if (!isNaN(intValue)) {
            Property.setProperty(path, intValue);
            Property.setFlag(path, 'ARCHIVE', true);
            sucessCode = true;
        } else {
            lWarn.logln("Typ-Fehler beim Speichern der Property " + path);
        }
        return sucessCode;
    }
    catch (e)
    {
        if (lWarn!=null)
        	lWarn.logln("Exception beim checkAndStoreIntParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

/**
 * Store a string property parameter.
 * check weather the provided value is a string. In case it's a number it is converted to string, 
 * in any other cases it is discarded
 * @param path [in] property path
 * @param value [in] value to store should be string or at least a number
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreStringParameter(path, value) {
    try 
    {
        if (lInfo!=null)
        	lInfo.logln('store string at |' + path + "| value: |" + value + "|" );
        var sucessCode = false;
        var stringValue = (typeof(value) === "number") ? String(value) : value;
        if (typeof(stringValue) === "string") {
            Property.setProperty(path, stringValue);
            Property.setFlag(path, 'ARCHIVE', true);
            sucessCode = true;
        } else {
            if (lWarn!=null)
            	lWarn.logln("Typ-Fehler beim Speichern der Property " + path);
        }
        return sucessCode;
    }
    catch (e)
    {
        if (lWarn!=null)
        	lWarn.logln("Exception beim checkAndStoreStringParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

/**
 * Store a dsuid as string property parameter.
 * check weather the provided value is a string. In case it's a number it is converted to string, 
 * if it is undefined it tries to convert dsid to dsuid, in any other cases it is discarded
 * @param path [in] property path
 * @param dsuid [in] value to store should be string
 * @param dsid [in] dsid value to be converted in dsuid if not available
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreDSUIDParameter(path, dsuid, dsid) {
    try 
    {
    	if (lInfo!=null)
    		lInfo.logln('store dsuid at |' + path + "| value: |" + dsuid + "|" );
        var successCode = false;
        var stringValue;
        if (typeof(dsuid) === 'string') {
            Property.setProperty(path, dsuid);
            Property.setFlag(path, 'ARCHIVE', true);
            successCode = true;
        } else {
            if (typeof(dsid) === 'string') {
                stringValue = dSID2dSUID(dsid);
                if (typeof(stringValue) === "string") {
                    Property.setProperty(path, stringValue);
                    Property.setFlag(path, 'ARCHIVE', true);
                    successCode = true;
                }
                if (lInfo!=null)
                	lInfo.logln("store converted dsid");
            } else {
            	if (lWarn!=null)
            		lWarn.logln('Typ-Fehler beim Speichern der Property ' + path)
            }
        }
        return successCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreDSUIDParameter " + e + " Path " + path  + " value " + dsuid);
        return false;
    }        
}

/**
 * Store a boolean property parameter.
 * convert value if possible. In case In case conversion is not possible 
 * the value is discarded.
 * @param path [in] property path
 * @param value [in] value to store should be a boolean
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreBoolParameter(path, value) {
    try 
    {
    	if (lInfo!=null)
    		lInfo.logln('store boolean at |' + path + "| value: |" + value + "|" );
        var successCode = false;
        var boolValue = false;
        if (typeof(value) === "boolean") {
            Property.setProperty(path, value);
            Property.setFlag(path, 'ARCHIVE', true);       
            successCode = true;
        } else {
            if (typeof(value) === "string") {
                if (value === "true") {
                    boolValue = true;
                }
                Property.setProperty(path, boolValue);
                Property.setFlag(path, 'ARCHIVE', true);       
                successCode = true;
            } else {
            	if (lWarn!=null)
            		lWarn.logln("Typ-Fehler beim Speichern der Property " + path);
            }
        }
        return successCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreBoolParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

function dSID2dSUID(dSID) {
    try {
        //copy the first 6 bytes (12 characters to the new dsuid
        var dSUID = dSID.slice(0, 12);
        //insert 4 bytes of 0
        dSUID += '00000000';
        //append the remaining 6 bytes (12 chars) of the dsid
        dSUID += dSID.slice(12, 24);
        //finaly add 1 byte of 0
        dSUID += '00';
        return dSUID;
    } catch (e) {
        if (lWarn!=null)
        	lWarn.logln('Exception in store-property-helper::dSID2dSUID ' + e);
        return '';
    }
}

/*Path : complete absolute path WITHOUT trailing "/" */
function putConditionParameter(path,oParameterObject) {
	var succeded = true;
	if (oParameterObject.conditions==null)
		return succeded;
	var sSubpath=path + '/conditions/';
	if (oParameterObject.conditions.enabled!=null) {
		if (oParameterObject.conditions.enabled==true)
			Property.setSavedProperty(sSubpath + 'enabled', true);
		else 
			Property.setSavedProperty(sSubpath + 'enabled', false);
	}	
	if (oParameterObject.conditions.weekdays!=null) {
		var sString="";
		for (var iIndex=0;iIndex<oParameterObject.conditions.weekdays.length;iIndex++) {
			var sWeekday=oParameterObject.conditions.weekdays[iIndex];
			switch (sWeekday)
			{
				case 'SU':
					sString += '0,';
				break;
				case 'MO':
					sString += '1,';
				break;
				case 'TU':
					sString += '2,';
				break;
				case 'WE':
					sString += '3,';
				break;
				case 'TH':
					sString += '4,';
				break;
				case 'FR':
					sString += '5,';
				break;
				case 'SA':
					sString += '6,';
				break;
			}	
		}
		if (sString!="") {
			sString=sString.substr(0,sString.length-1);
			Property.setSavedProperty(sSubpath + 'weekdays', sString);
		}
	}	
	if (oParameterObject.conditions.systemState!=null) {
		for (var iIndex=0;iIndex<oParameterObject.conditions.systemState.length;iIndex++){
			var sStateName=oParameterObject.conditions.systemState[iIndex].name;
			var sStateValue=oParameterObject.conditions.systemState[iIndex].value;
			if (sStateValue==='false')
				sStateValue=false;
			if (sStateValue==='true')
				sStateValue=true;
			Property.setSavedProperty(sSubpath + 'states/' + sStateName,sStateValue);
		}
	}	
	if (oParameterObject.conditions.addonStates!=null) {
		for (var sAddonId in oParameterObject.conditions.addonStates) {
			for (var iIndex=0;iIndex<oParameterObject.conditions.addonStates[sAddonId].length;iIndex++){
				var sStateName=oParameterObject.conditions.addonStates[sAddonId][iIndex].name;
				var sStateValue=oParameterObject.conditions.addonStates[sAddonId][iIndex].value;
				if (sStateValue==='false')
					sStateValue=2;
				if (sStateValue==='true')
					sStateValue=1;
				if (sStateValue===false)
					sStateValue=2;
				if (sStateValue===true)
					sStateValue=1;
				Property.setSavedProperty(sSubpath + 'addon-states/' + sAddonId + '/' + sStateName,sStateValue);
			}
		}
	}	
	if (oParameterObject.conditions.zoneState!=null) {
		for (var iIndex=0;iIndex<oParameterObject.conditions.zoneState.length;iIndex++){ 
			var zoneID=oParameterObject.conditions.zoneState[iIndex].zone;
			var groupID=oParameterObject.conditions.zoneState[iIndex].group;
			var sceneID=oParameterObject.conditions.zoneState[iIndex].scene;
			
			succeded = checkAndStoreIntParameter(sSubpath + 'zone-states/' + iIndex + '/zone' , zoneID) ? succeded : false;
			succeded = checkAndStoreIntParameter(sSubpath + 'zone-states/' + iIndex + '/group' , groupID) ? succeded : false;
			succeded = checkAndStoreIntParameter(sSubpath + 'zone-states/' + iIndex + '/scene' , sceneID) ? succeded : false;
		}
	}	
	if (oParameterObject.conditions.timeframe!=null) {
		for (var iIndex=0;iIndex<oParameterObject.conditions.timeframe.length;iIndex++){ 
			var from=oParameterObject.conditions.timeframe[iIndex].start;
			var to=oParameterObject.conditions.timeframe[iIndex].end;
			var sFromBase=from.timeBase;
			var sFromOffset=from.offset;
			var sToBase=to.timeBase;
			var sToOffset=to.offset;
			lInfo.logln('from ' + sFromBase + ' off ' + sFromOffset + ' to  ' + sToBase + ' off ' + sToOffset);
			if (sFromBase=='daily')
				if (sToBase=='daily'){
					Property.setSavedProperty(sSubpath + 'time-start' , Math.floor(parseInt("" + sFromOffset,10)/3600) + ':' + Math.floor(parseInt("" + sFromOffset,10)/60)%60 + ':' + Math.floor(parseInt("" + sFromOffset,10)%60));
					Property.setSavedProperty(sSubpath + 'time-end'  , Math.floor(parseInt("" + sToOffset,10)/3600) + ':' + Math.floor(parseInt("" + sToOffset,10)/60)%60 + ':' + Math.floor(parseInt("" + sToOffset,10)%60));
				}
		}	
	}	
	if (oParameterObject.conditions.date!=null) {
		for (var iIndex=0;iIndex<oParameterObject.conditions.date.length;iIndex++){
			var from=oParameterObject.conditions.date[iIndex].start;
			var to=oParameterObject.conditions.date[iIndex].end;
			var rrule=oParameterObject.conditions.date[iIndex].rrule;
			
			Property.setSavedProperty(sSubpath + 'date/' + iIndex + '/start' , from );
			Property.setSavedProperty(sSubpath + 'date/' + iIndex + '/end'  , to);
			Property.setSavedProperty(sSubpath + 'date/' + iIndex + '/rrule'  , rrule);
			
		}
	} 
	return succeded;
}

/*Path : complete absolute path WITHOUT trailing "/" */
function putTriggerParameter(path,oParameterObject) {
	var succeded = true;
	var iIndex;
    for (iIndex=0;iIndex<oParameterObject.triggers.length;iIndex++)
    {
        var sSubpath=path + '/triggers/' + (iIndex + 1) + "/";
        switch(oParameterObject.triggers[iIndex].type) {
        	case 'bus-zone-scene':
            case 'zone-scene':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "zone" , oParameterObject.triggers[iIndex].zone) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "group" , oParameterObject.triggers[iIndex].group) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "scene" , oParameterObject.triggers[iIndex].scene) ? succeded : false;
                if (oParameterObject.triggers[iIndex].forced!=null)
                	succeded = checkAndStoreBoolParameter(sSubpath + "forced" , oParameterObject.triggers[iIndex].forced) ? succeded : false;
                if (oParameterObject.triggers[iIndex].dsuid!=null)
                	Property.setSavedProperty(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid);
                else
                	Property.setSavedProperty(sSubpath + "dsuid" , -1);
                break;
            case 'bus-undo-zone-scene':
            case 'undo-zone-scene':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "zone" , oParameterObject.triggers[iIndex].zone) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "group" , oParameterObject.triggers[iIndex].group) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "scene" , oParameterObject.triggers[iIndex].scene) ? succeded : false;
                if (oParameterObject.triggers[iIndex].dsuid!=null)
                	Property.setSavedProperty(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid);
                else
                	Property.setSavedProperty(sSubpath + "dsuid" , -1);
                break;
            case 'device-msg':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid, oParameterObject.triggers[iIndex].dsid) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "msg" , oParameterObject.triggers[iIndex].msg) ? succeded : false;
                if (oParameterObject.triggers[iIndex].buttonIndex!=null)
                	succeded = checkAndStoreIntParameter(sSubpath + "buttonIndex" , oParameterObject.triggers[iIndex].buttonIndex) ? succeded : false;
                break;
            case 'device-action':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid, oParameterObject.triggers[iIndex].dsid) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "action" , oParameterObject.triggers[iIndex].action) ? succeded : false;
            	break;
            case 'device-binary-input':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "index" , oParameterObject.triggers[iIndex].index) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "state" , oParameterObject.triggers[iIndex].state) ? succeded : false;
                break;
            case 'device-scene':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid, oParameterObject.triggers[iIndex].dsid) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "scene" , oParameterObject.triggers[iIndex].scene) ? succeded : false;
                break;
            case 'custom-event':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath + "event" , oParameterObject.triggers[iIndex].event) ? succeded : false;
                break;
            case 'device-sensor':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid, oParameterObject.triggers[iIndex].dsid) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "eventid" , oParameterObject.triggers[iIndex].eventid) ? succeded : false;
                break;
            case 'device-named-event':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid, oParameterObject.triggers[iIndex].dsid) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "id" , oParameterObject.triggers[iIndex].id) ? succeded : false;
                break;
            case 'device-named-action':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath + "dsuid" , oParameterObject.triggers[iIndex].dsuid, oParameterObject.triggers[iIndex].dsid) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "id" , oParameterObject.triggers[iIndex].id) ? succeded : false;
                break;
            case 'state-change':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "name" , oParameterObject.triggers[iIndex].name) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "state" , oParameterObject.triggers[iIndex].state) ? succeded : false;
                break;
            case 'addon-state-change':
            	succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "addon-id" , oParameterObject.triggers[iIndex].addonId) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "name" , oParameterObject.triggers[iIndex].name) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath + "state" , oParameterObject.triggers[iIndex].state) ? succeded : false;
                break;
            case 'event':
                succeded = checkAndStoreStringParameter(sSubpath + "type" , oParameterObject.triggers[iIndex].type) ? succeded : false;
                succeded = checkAndStoreStringParameter(sSubpath + "name" , oParameterObject.triggers[iIndex].name) ? succeded : false;
                sSubpath += "parameter/";
                for (var key in oParameterObject.triggers[iIndex].parameter) {
                    succeded = checkAndStoreStringParameter(sSubpath + key , oParameterObject.triggers[iIndex].parameter[key]) ? succeded : false;
                }
                break;
        }
    }
    return succeded;
}

function putActionParameter(path,oParameterObject,category) {
	var iIndex;
	var succeded = true;
    for (iIndex = 0; iIndex < oParameterObject.actions.length; iIndex++) {
        var oSubobject = oParameterObject.actions[iIndex];
        var sSubpath=path + '/actions/' + iIndex + "/";
        switch (oSubobject.type) {
	        case 'device-action':
		    	succeded = checkAndStoreStringParameter(sSubpath + 'type', oSubobject.type) ? succeded : false ;
	        	succeded = checkAndStoreDSUIDParameter(sSubpath+ 'dsuid', oSubobject.dsuid, oSubobject.dsid) ? succeded : false;
	            succeded = checkAndStoreStringParameter(sSubpath+ 'id', oSubobject.id) ? succeded : false;
	        break;
		    case 'heating-mode':
		    	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false ;
		    	succeded = checkAndStoreIntParameter(sSubpath+ 'zone', oSubobject.zone) ? succeded : false ;
		    	if (oSubobject.reset!=null)
		    		succeded = checkAndStoreBoolParameter(sSubpath+ 'reset', oSubobject.reset) ? succeded : false;
		    	succeded = checkAndStoreIntParameter(sSubpath+ 'mode', oSubobject.mode) ? succeded : false;
		    break;
		    case 'zone-scene':
		    	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false ;
		    	succeded = checkAndStoreIntParameter(sSubpath+ 'zone', oSubobject.zone) ? succeded : false ;
		    	succeded = checkAndStoreIntParameter(sSubpath+ 'group', oSubobject.group) ? succeded : false ;
		    	succeded = checkAndStoreIntParameter(sSubpath+ 'scene', oSubobject.scene) ? succeded : false;
		    	if (oSubobject.force!=null)
		    		succeded = checkAndStoreBoolParameter(sSubpath+ 'force', oSubobject.force) ? succeded : false;
		    break;
            case 'undo-zone-scene':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'zone', oSubobject.zone) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'group', oSubobject.group) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'scene', oSubobject.scene) ? succeded : false;
            	if (oSubobject.force!=null)
            		succeded = checkAndStoreBoolParameter(sSubpath+ 'force', oSubobject.force) ? succeded : false;
            break;
            case 'device-scene':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath+ 'dsuid' , oSubobject.dsuid, oSubobject.dsid) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'scene', oSubobject.scene) ? succeded : false;
            	if (oSubobject.force!=null)
            		succeded = checkAndStoreBoolParameter(sSubpath+ 'force', oSubobject.force) ? succeded : false;
            break;
            case 'device-value':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'value', oSubobject.value) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath+ 'dsuid' , oSubobject.dsuid, oSubobject.dsid) ? succeded : false;
            break;            
            case 'device-blink':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	succeded = checkAndStoreDSUIDParameter(sSubpath+ 'dsuid' , oSubobject.dsuid, oSubobject.dsid) ? succeded : false;
            break;
            case 'zone-blink':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'zone', oSubobject.zone) ? succeded : false;
            	succeded = checkAndStoreIntParameter(sSubpath+ 'group', oSubobject.group) ? succeded : false;
            break;
            case 'custom-event':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	succeded = checkAndStoreStringParameter(sSubpath+ 'event', oSubobject.event) ? succeded : false;
            break;
            case 'url':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
                oSubobject.url = oSubobject.url.replace(/&amp;/g, '&');
            	succeded = checkAndStoreStringParameter(sSubpath+ 'url', Utf8.encode(unescape(oSubobject.url))) ? succeded : false;
            break;
            case 'change-state':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	if (oSubobject.name!=null)
            		succeded = checkAndStoreStringParameter(sSubpath + "statename" , oSubobject.name) ? succeded : false;
            	else
            		succeded = checkAndStoreStringParameter(sSubpath + "statename" , oSubobject.statename) ? succeded : false;

               succeded = checkAndStoreStringParameter(sSubpath + "state" , oSubobject.state);
            break;            
            case 'change-addon-state':
            	succeded = checkAndStoreStringParameter(sSubpath+ 'type', oSubobject.type) ? succeded : false;
            	if (oSubobject.name!=null)
            		succeded = checkAndStoreStringParameter(sSubpath +"statename" , oSubobject.name) ? succeded : false;
            	else
            		succeded = checkAndStoreStringParameter(sSubpath +"statename" , oSubobject.statename) ? succeded : false;

            	succeded = checkAndStoreStringParameter(sSubpath + "addon-id" , oSubobject.addonId) ? succeded : false;
                succeded = checkAndStoreStringParameter(sSubpath + "state" , oSubobject.state) ? succeded : false;
            break;
            default:
            	//unexpected type 
            	succeded = false;
            break;
        }
        if (oSubobject.delay!=null) {
        	succeded = checkAndStoreIntParameter(sSubpath+ 'delay', oSubobject.delay) ? succeded : false;
        }
        if (category==null)
        	Property.setSavedProperty(sSubpath+ 'category', 'manual');
        else
        	Property.setSavedProperty(sSubpath+ 'category', category);
    }
    return succeded;
}
